.. _changelog:

==========
Change Log
==========


v0.1.0 (2019/3/29)
==================
First official release, but API is not guaranteed to be stable.

- Add more docs to :ref:`reference`.

v0.0.1 (2019/1/1)
=================
Pre-release.
